<?php if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class Vatansms_SMS_Archive_List_Table extends WP_List_Table {

	public static $table = 'woocommerce_ir_sms_archive';

	public function __construct() {

		parent::__construct( array(
			'singular' => 'SMS Raporları',
			'plural'   => 'SMS Raporları',
			'ajax'     => false
		) );
	}

	public function no_items() {
		echo 'bulunamadı.';
	}

	public function get_sortable_columns() {
		$sortable_columns = array(
			'post_id'  => array( 'post_id', false ),
			'type'     => array( 'type', false ),
			'sender'   => array( 'sender', false ),
			'reciever' => array( 'reciever', false ),
			'date'     => array( 'date', false ),
		);

		return $sortable_columns;
	}

	public function get_columns() {
		$columns = array(
			'cb'       => '<input type="checkbox" />',
			'date'     => 'zaman',
			'post_id'  => 'Sipariş / Ürün',
			'type'     => 'Mesaj türü',
			'message'  => 'Mesaj İçeriği',
			'reciever' => 'Alıcılar',
			'sender'   => 'WebServıse',
			'result'   => 'İşlem Sonucu',
		);

		return $columns;
	}

	public function column_default( $item, $column_name ) {
		$align = is_rtl() ? 'right' : 'left';
		switch ( $column_name ) {

			case 'sender':
			case 'reciever':
				return '<div style="direction:ltr !important;text-align:' . $align . ';">' . $item[ $column_name ] . '</div>';
				break;

			default:
				if ( is_string( $item[ $column_name ] ) ) {
					return nl2br( $item[ $column_name ] );
				}

				return print_r( $item[ $column_name ], true );
				break;
		}
	}

	public function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="item[]" value="%s" />', $item['id']
		);
	}

	public function column_post_id( $item ) {

		if ( empty( $item['post_id'] ) ) {
			return '-';
		}

		$post_id   = intval( $item['post_id'] );
		$post_type = get_post_type( $post_id );

		$value = array();
		switch ( $post_type ) {

			case 'shop_order':
				$edit_title   = 'Sipariş yönetimi';
				$filter_title = 'Bu siparişin SMS arşivini görüntüle';
				$value[]      = 'Sipariş #' . $post_id;
				break;

			case 'product':
				$edit_title   = 'Ürün yönetimi';
				$filter_title = 'Bu ürünün SMS arşivini görüntüle';
				$value[]      = 'Ürün';
				$value[]      = get_the_title( $post_id );
				break;

			default:
				return '-';
		}

		$actions = array(
			'delete' => sprintf( '<a target="_blank" href="%s">%s</a>', get_edit_post_link( $post_id ), $edit_title ),
		);

		$post_id = '<a title="' . $filter_title . '" href="' . add_query_arg( array( 'id' => $post_id ) ) . '">' . implode( ' :: ', $value ) . '</a>';

		return sprintf( '%1$s %2$s', $post_id, $this->row_actions( $actions ) );
	}

	public function column_result( $item ) {

		$result = ! empty( $item['result'] ) ? $item['result'] : '';
		if ( trim( $result ) == '_ok_' ) {
			$result = 'SMS başarıyla gönderildi.';
		}

		return $result;
	}

	public function column_type( $item ) {

		if ( empty( $item['type'] ) ) {
			return '-';
		}

		switch ( $item['type'] ) {

			case '1':
				$value = 'Toplu olarak gönder';
				break;

			/*مشتری*/
			case '2':
				$value = 'Müşteri - Otomatik - Sipariş';
				break;

			case '3':
				$value = 'Müşteri - Kılavuz - Metabax Siparişi';
				break;

			/*مدیر کل*/
			case '4':
				$value = 'Genel Müdür - Otomatik - Sipariş';
				break;

			/* مدیر محصول*/
			case '5':
				$value = 'Ürün Yöneticisi - Otomatik - Sipariş';
				break;

			case '6':
				$value = 'Ürün Yöneticisi - Kılavuz - Metabox Ürünü';
				break;

			/*مشترک مدیر کل و مدیر محصول*/
			case '7':
				$value = 'Yöneticiler - otomatik - mevcut değil';
				break;

			case '8':
				$value = 'Yöneticiler - Otomatik - Düşük envanter';
				break;

			/*خبرنامه*/
			case '9':
				$value = 'Bülten - Açık Artırma - Otomatik';
				break;

			case '10':
				$value = 'خبرنامه - حراج شدن - دستی';
				break;
			/*--*/
			case '11':
				$value = 'خبرنامه - موجود شدن - اتوماتیک';
				break;

			case '12':
				$value = 'خبرنامه - موجود شدن - دستی';
				break;
			/*--*/
			case '13':
				$value = 'خبرنامه - کم بودن موجودی - اتوماتیک';
				break;

			case '14':
				$value = 'خبرنامه - کم بودن موجودی - دستی';
				break;
			/*--*/
			case '15':
				$value = 'خبرنامه - گزینه های دلخواه - دستی';
				break;

			default:
				$value = '';
		}

		return $value;
	}

	public function column_date( $item ) {

		$delete_nonce = wp_create_nonce( 'pwoosms_delete_archive' );

		$url = add_query_arg( array(
			'action'   => 'delete',
			'item'     => absint( $item['id'] ),
			'_wpnonce' => $delete_nonce
		) );

		$actions = array(
			'delete' => sprintf( '<a href="%s">%s</a>', $url, 'Sil' ),
		);

		$date = date_i18n( 'Y-m-d H:i:s', strtotime( $item['date'] ) );
		$date = PWooSMS()->mayBeJalaliDate( $date );

		return sprintf( '%1$s %2$s', $date, $this->row_actions( $actions ) );
	}

	public function prepare_items() {
		$columns               = $this->get_columns();
		$hidden                = array();
		$sortable              = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );
		$this->process_bulk_action();

		$per_page     = 20;
		$current_page = $this->get_pagenum();
		$total_items  = $this->record_count();

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page'    => $per_page
		) );
		$this->items = $this->get_items( $per_page, $current_page );
	}

	public function get_bulk_actions() {
		$actions = array(
			'bulk_delete' => 'Sil'
		);

		return $actions;
	}

	public function process_bulk_action() {

		$action = $this->current_action();

		if ( 'delete' === $action ) {

			if ( ! empty( $_REQUEST ) && ! wp_verify_nonce( sanitize_text_field( $_REQUEST['_wpnonce'] ), 'pwoosms_delete_archive' ) ) {
				die( 'Bir hata oluştu. Sonra dene.' );
			}

			$this->delete_item( absint( $_REQUEST['item'] ) );

			echo '<div class="updated notice is-dismissible below-h2"><p>silindi.</p></div>';
		} else if ( $action == 'bulk_delete' ) {

			if ( ! empty( $_REQUEST ) && ! wp_verify_nonce( sanitize_text_field( $_REQUEST['_wpnonce'] ), 'bulk-' . $this->_args['plural'] ) ) {
				die( 'Bir hata oluştu. Sonra deneç' );
			}

			$delete_ids = isset( $_REQUEST['item'] ) ? esc_sql( $_REQUEST['item'] ) : array();
			foreach ( (array) $delete_ids as $id ) {
				$this->delete_item( absint( $id ) );
			}

			echo '<div class="updated notice is-dismissible below-h2"><p>silindi</p></div>';
		}
	}

	/*--------------------------------------------*/
	public static function table() {
		global $wpdb;

		return $wpdb->prefix . self::$table;
	}

	private function table_exists() {
		global $wpdb;

		return $wpdb->get_var( "SHOW TABLES LIKE '" . self::table() . "'" );
	}

	private function get_query( $count = false ) {

		global $wpdb;

		$select = $count ? 'count(*)' : '*';

		$sql = "SELECT {$select} FROM " . self::table();

		if ( isset( $_REQUEST['s'] ) ) {
			$s   = $wpdb->esc_like( $_REQUEST['s'] );
			$s   = ltrim( $s, '0' );
			$sql .= ' WHERE (`message` LIKE "%' . $s . '%" OR `reciever` LIKE "%' . $s . '%"  OR `sender` LIKE "%' . $s . '%")';
		}

		if ( ! empty( $_REQUEST['id'] ) ) {
			$post_id = $_REQUEST['id'];
			$post_id = ! is_array( $post_id ) ? explode( ',', (string) $post_id ) : $post_id;
			$post_id = array_unique( array_filter( array_map( 'intval', $post_id ) ) );
			$sql     .= ( isset( $s ) ? ' AND' : ' WHERE' ) . ' (`post_id` IN (' . implode( ',', $post_id ) . '))';
		}

		if ( ! empty( $_REQUEST['orderby'] ) ) {
			$sql .= ' ORDER BY ' . esc_sql( $_REQUEST['orderby'] );
			$sql .= ! empty( $_REQUEST['order'] ) ? ' ' . esc_sql( $_REQUEST['order'] ) : ' ASC';
		} else {
			$sql .= ' ORDER BY id DESC';
		}

		return $sql;
	}

	public function record_count() {

		if ( ! $this->table_exists() ) {
			return 0;
		}

		global $wpdb;

		return $wpdb->get_var( $this->get_query( true ) );
	}

	public function get_items( $per_page = 20, $page_number = 1 ) {

		global $wpdb;
		if ( ! $this->table_exists() ) {
			return array();
		}

		$sql    = $this->get_query();
		$sql    .= " LIMIT $per_page";
		$sql    .= ' OFFSET ' . ( $page_number - 1 ) * $per_page;
		$result = $wpdb->get_results( $sql, 'ARRAY_A' );

		return $result;
	}

	public function delete_item( $id ) {
		global $wpdb;

		$wpdb->delete( self::table(), array( 'id' => $id ) );
	}

}

class Vatansms_SMS_Archive {

	public function __construct() {
		add_action( 'pwoosms_settings_form_bottom_sms_archive', array( $this, 'archiveTable' ) );
		add_action( 'init', array( $this, 'createTable' ) );
	}

	public function createTable() {

		if ( get_option( 'pwoosms_table_archive' ) ) {
			return;
		}

		if ( ! function_exists( 'dbDelta' ) ) {
			require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
		}

		global $wpdb;

		$charset_collate = '';
		if ( ! empty( $wpdb->charset ) ) {
			$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
		}
		if ( ! empty( $wpdb->collate ) ) {
			$charset_collate .= " COLLATE $wpdb->collate";
		}

		$table = Vatansms_SMS_Archive_List_Table::table();
		dbDelta( "CREATE TABLE IF NOT EXISTS $table (
			id mediumint(8) unsigned NOT NULL auto_increment,
			post_id mediumint(8) unsigned,
            type tinyint(2),
			reciever TEXT NOT NULL,
			message TEXT NOT NULL,
			sender VARCHAR(100),
			result TEXT,
			date DATETIME,
			PRIMARY KEY  (id)
		) $charset_collate;" );

		update_option( 'pwoosms_table_archive', '1' );
	}

	public static function insertRecord( $data ) {

		global $wpdb;

		$time = time();
		if ( function_exists( 'wc_timezone_offset' ) ) {
			$time += wc_timezone_offset();
		}

		$wpdb->insert( Vatansms_SMS_Archive_List_Table::table(), array(
			'post_id'  => ! empty( $data['post_id'] ) ? $data['post_id'] : 0,
			'type'     => ! empty( $data['type'] ) ? $data['type'] : 0,
			'reciever' => ! empty( $data['reciever'] ) ? $data['reciever'] : '',
			'message'  => ! empty( $data['message'] ) ? $data['message'] : '',
			'sender'   => ! empty( $data['sender'] ) ? $data['sender'] : '',
			'result'   => ! empty( $data['result'] ) ? $data['result'] : '',
			'date'     => gmdate( 'Y-m-d H:i:s', $time ),
		), array( '%d', '%d', '%s', '%s', '%s', '%s', '%s' ) );
	}

	public function archiveTable() {
		$list = new Vatansms_SMS_Archive_List_Table();
		$list->prepare_items();

		echo '<span class="description">SMS Arşiv</span>';

		echo '<style type="text/css">';
		echo '.wp-list-table .column-id { max-width: 5%; }';
		echo '</style>';
		?>

		<?php if ( ! empty( $_GET['id'] ) ) : ?>
            <a class="page-title-action" href="<?php echo remove_query_arg( array( 'id' ) ); ?>">Arşiv listesine dön</a>
		<?php endif; ?>

        <form method="post">
            <input type="hidden" name="page" value="Vatansms_SMS_Archive_list_table">
			<?php
			$list->search_box( 'Arama ', 'search_id' );
			$list->display();
			?>
        </form>

        <script type="text/javascript">
            jQuery( document ).ready( function ( $ ) {
                $( '.delete a, a.delete, .button.action' ).on( 'click', function ( e ) {
                    var action1 = $( 'select[name="action"]' ).val();
                    var action2 = $( 'select[name="action2"]' ).val();
                    if ( $( this ).is( 'a' ) || action1 === 'bulk_delete' || action2 === 'bulk_delete' ) {
                        if ( !confirm( 'Silmek istediğinizden emin misiniz? Bu geri döndürülemez.' ) ) {
                            e.preventDefault();
                            return false;
                        }
                    }
                } );
            } );
        </script>
		<?php
	}

}

new Vatansms_SMS_Archive();